==> ACME_2.6.0.zip: ACME/doc/ACME.R <==
###################################################
### chunk number 1: 
###################################################
#line 38 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
library(ACME)


###################################################
### chunk number 2: 
###################################################
#line 46 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
datdir <- system.file('extdata',package='ACME')
fnames <- dir(datdir)
example.agff <- read.resultsGFF(fnames,path=datdir)
example.agff


###################################################
### chunk number 3: 
###################################################
#line 55 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
calc <- do.aGFF.calc(example.agff,window=1000,thresh=0.95)


###################################################
### chunk number 4: 
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
plot(calc,chrom='chr1',sample=1)


###################################################
### chunk number 5: 
###################################################
#line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
regs <- findRegions(calc)
regs[1:5,]


###################################################
### chunk number 6: 
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDSMFe7/R.INSTALL68f012b4/ACME/inst/doc/ACME.Rnw"
# write both calculated values and raw data
write.sgr(calc)
# OR write only calculated data
write.sgr(calc,raw=FALSE)

==> ACME_2.65.0.zip: ACME/doc/ACME.R <==
### R code from vignette source 'ACME.Rnw'

###################################################
### code chunk number 1: ACME.Rnw:37-38
###################################################
library(ACME)


###################################################
### code chunk number 2: ACME.Rnw:45-49
###################################################
datdir <- system.file('extdata',package='ACME')
fnames <- dir(datdir)
example.agff <- read.resultsGFF(fnames,path=datdir)
example.agff


###################################################
### code chunk number 3: ACME.Rnw:54-55
###################################################
calc <- do.aGFF.calc(example.agff,window=1000,thresh=0.95)


###################################################
### code chunk number 4: ACME.Rnw:62-63
###################################################
plot(calc,chrom='chr1',sample=1)


###################################################
### code chunk number 5: ACME.Rnw:68-70
###################################################
regs <- findRegions(calc)
regs[1:5,]


###################################################
### code chunk number 6: ACME.Rnw:77-81
###################################################
# write both calculated values and raw data
write.sgr(calc)
# OR write only calculated data
write.sgr(calc,raw=FALSE)


###################################################
### code chunk number 7: ACME.Rnw:86-88
###################################################
# or for the UCSC genome browser
write.bedGraph(calc)
